==> ev_framework-3.0.2.tar.gz: lib/_FrameWork/vSystem.dart <==
import 'dart:io';
import 'package:connectivity/connectivity.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:url_launcher/url_launcher.dart';
import 'vApi.dart';
import 'vFirebase.dart';
import 'vPopup.dart';

class vSystem
{  static String Lang_id = "0";

   static  Map _LocValue = Map();
   static  Map Lang_eng = Map();
   static  Map Lang_chi = Map();
   static  Map _LangStr;

   static var _Screen = ["Mobile", "Tablet", "Destop", "Large Screen"];

   static var Screen_id = 0;

    vSystem(StartApp, {int default_lang_id=1,}) {

     WidgetsFlutterBinding.ensureInitialized();
     SharedPreferences.getInstance().then((res) async {
       await _init_lang(default_lang_id);
       await _init_LocalValue(res);
       runApp(StartApp);
     });
   }

    vSystem Mobile() {
      WidgetsFlutterBinding.ensureInitialized();
         SystemChrome.setPreferredOrientations([
          DeviceOrientation.portraitUp,
          DeviceOrientation.portraitDown,
         ]);
      return this;
      }


   Future<vSystem>  firebaseConnect({String topic=""})
   async {
      await vFirebase.connect(topic);
    }

  static Future<bool> $check_network() async
    { var connectivityResult = await (Connectivity().checkConnectivity());
        if (connectivityResult == ConnectivityResult.mobile ||
            connectivityResult == ConnectivityResult.wifi) {
            return true;
         }
        else {
            return false;
       }
      }

    static Future<void> $open_URL(String url,{error}) async {
        if (await canLaunch(url)) { await launch(url); }
    else {
        if(error != null)
          { error(); }
      }
    }


static int screensize_ID(BuildContext context)
   { var maxWidth = MediaQuery.of(context).size.width;
     if(maxWidth<=400)
       { Screen_id = 0;  return 0;}
     if(maxWidth>400 &&  maxWidth<=800)
       { Screen_id = 1; return 1; }
     if(maxWidth>800 &&  maxWidth<=1200)
       { vSystem.Screen_id = 2; return 2;}
     vSystem.Screen_id = 3;
     return 3;
   }

 static Future<void> _init_lang(int default_lang_id) async {
   var lang = $local("lang");
   if (lang == "") {
      Lang_id = default_lang_id.toString();
    }
    else {
      Lang_id = lang;
   }
   _assign_lang();
 }

static _assign_lang()
{ switch(Lang_id) {
   case "1":
    _LangStr = Lang_eng;
    break;

   case "2":
    _LangStr = Lang_chi;
    break;

   default:
    _LangStr = Lang_eng;
 }
  $local_Set("lang", Lang_id);
}


static void _init_LocalValue(SharedPreferences prefs)
      {  prefs.getKeys().forEach((String key){
        _LocValue[key] = prefs.getString(key) ?? '' ;
        });
      }

   static String $device()
   {  return  _Screen[Screen_id]; }


   static _$set_LangId(int lang_id,Map mapstring)
      { _LangStr[lang_id] =  mapstring;
        //print("Set Lang : $lang_id" +_LangStr.toString());
      }

   static void $lang_Chi() {
       Lang_id = "2";
       _assign_lang();
   }

   static void $lang_Eng() {
       Lang_id = "1";
       _assign_lang();
   }

   static String lang_text(String text)
     {  return _LangStr[text] ?? text; }

   static String $lang_id()
    {   return Lang_id ; }

   static String $local(String LocalStore_Name)
      { return _LocValue[LocalStore_Name] ?? '' ; }

  static $local_Set(String LocalStore_Name,String value) async {
      _LocValue[LocalStore_Name] = value;
      final SharedPreferences prefs = await SharedPreferences.getInstance();
      prefs.setString(LocalStore_Name, value);
    }

  static Widget $CheckVersion(String checkversion_url,String app_version,child)
  {  return _MainBody(checkversion_url,app_version,child); }

}

void  _CheckVersion(BuildContext Context,String url,String version)
 async {
  bool network = await vSystem.$check_network();
  if (network) {
    var post = {"version_number": version};
    var api = vApi();
    api.$post(url, postValue: post, onData: (js) {
      var sdata = js["sdata"];
      vPopup.$YesNo(Context, sdata["title"], sdata["message"],
          yes_text: sdata["update"], no_text: sdata["close"],
          onNo: () {
            if (sdata["status"] == 2) {
              exit(0);
            }
          },
          onYes: () async {
            if (Platform.isAndroid) {
              await launch(sdata["andriod"]); // Android-specific code
            }
            else if (Platform.isIOS) {
              await launch(sdata["ios"]);
            }
            exit(0);
          }
      );
    });
  }
}


class _MainBody extends StatefulWidget {
  var url;
  var app_version;
  var child;

  _MainBody(this.url,this.app_version,this.child);

  @override
  __MainBodyState createState() => __MainBodyState();
}

class __MainBodyState extends State<_MainBody> {
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    WidgetsBinding.instance.addPostFrameCallback((_) => _CheckVersion(context,widget.url,widget.app_version));
    return widget.child;
  }
}

==> ev_framework-3.0.5.tar.gz: lib/_FrameWork/vSystem.dart <==
import 'dart:io';
import 'package:connectivity/connectivity.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:url_launcher/url_launcher.dart';
import 'vApi.dart';
import 'vFirebase.dart';
import 'vPopup.dart';

class vSystem
{  static String Lang_id = "0";

   static  Map _LocValue = Map();
   static  Map Lang_eng = Map();
   static  Map Lang_chi = Map();
   static  Map _LangStr;

   static var _Screen = ["Mobile", "Tablet", "Destop", "Large Screen"];

   static var Screen_id = 0;

    vSystem(StartApp, {int default_lang_id=1,}) {

     WidgetsFlutterBinding.ensureInitialized();
     SharedPreferences.getInstance().then((res) async {
       await _init_lang(default_lang_id);
       await _init_LocalValue(res);
       runApp(StartApp);
     });
   }

    vSystem Mobile() {
      WidgetsFlutterBinding.ensureInitialized();
         SystemChrome.setPreferredOrientations([
          DeviceOrientation.portraitUp,
          DeviceOrientation.portraitDown,
         ]);
      return this;
      }


   Future<vSystem>  firebaseConnect({String topic=""})
   async {
      await vFirebase.connect(topic);
    }

  static Future<bool> $check_network() async
    { var connectivityResult = await (Connectivity().checkConnectivity());
        if (connectivityResult == ConnectivityResult.mobile ||
            connectivityResult == ConnectivityResult.wifi) {
            return true;
         }
        else {
            return false;
       }
      }

    static Future<void> $open_URL(String url,{error}) async {
        if (await canLaunch(url)) { await launch(url); }
    else {
        if(error != null)
          { error(); }
      }
    }


static int screensize_ID(BuildContext context)
   { var maxWidth = MediaQuery.of(context).size.width;
     if(maxWidth<=400)
       { Screen_id = 0;  return 0;}
     if(maxWidth>400 &&  maxWidth<=800)
       { Screen_id = 1; return 1; }
     if(maxWidth>800 &&  maxWidth<=1200)
       { vSystem.Screen_id = 2; return 2;}
     vSystem.Screen_id = 3;
     return 3;
   }

 static Future<void> _init_lang(int default_lang_id) async {
   var lang = $local("lang");
   if (lang == "") {
      Lang_id = default_lang_id.toString();
    }
    else {
      Lang_id = lang;
   }
   _assign_lang();
 }

static _assign_lang()
{ switch(Lang_id) {
   case "1":
    _LangStr = Lang_eng;
    break;

   case "2":
    _LangStr = Lang_chi;
    break;

   default:
    _LangStr = Lang_eng;
 }
  $local_Set("lang", Lang_id);
}


static void _init_LocalValue(SharedPreferences prefs)
      {  prefs.getKeys().forEach((String key){
        _LocValue[key] = prefs.getString(key) ?? '' ;
        });
      }

   static String $device()
   {  return  _Screen[Screen_id]; }


   static _$set_LangId(int lang_id,Map mapstring)
      { _LangStr[lang_id] =  mapstring;
        //print("Set Lang : $lang_id" +_LangStr.toString());
      }

   static void $lang_Chi() {
       Lang_id = "2";
       _assign_lang();
   }

   static void $lang_Eng() {
       Lang_id = "1";
       _assign_lang();
   }

   static String lang_text(String text)
     {  return _LangStr[text] ?? text; }

   static String $lang_id()
    {   return Lang_id ; }

   static String $local(String LocalStore_Name)
      { return _LocValue[LocalStore_Name] ?? '' ; }

  static $local_Set(String LocalStore_Name,String value) async {
      _LocValue[LocalStore_Name] = value;
      final SharedPreferences prefs = await SharedPreferences.getInstance();
      prefs.setString(LocalStore_Name, value);
    }

  static Widget $CheckVersion(String checkversion_url,String app_version,child)
  {  return _MainBody(checkversion_url,app_version,child); }

}

void  _CheckVersion(BuildContext Context,String url,String version)
async {
  bool network = await vSystem.$check_network();
  if (network) {
    var post = {"version_number": version};
    var api = vApi();

    api.$post(url, postValue: post, onData: (js) {
      var sdata = js["sdata"];
      if(js["status"]>0)
      { vPopup.$YesNo(Context, sdata["title"], sdata["message"],
          yes_text: sdata["update"], no_text: sdata["close"],
          onNo: () {
            if (sdata["status"] == 2) {
              exit(0);
            }
          },
          onYes: () async {
            if (Platform.isAndroid) {
              await launch(sdata["andriod"]); // Android-specific code
            }
            else if (Platform.isIOS) {
              await launch(sdata["ios"]);
            }
            exit(0);
          }
      );
      }
    });
  }}


class _MainBody extends StatelessWidget {
  var url;
  var app_version;
  var child;
  var checked = false;
  _MainBody(this.url,this.app_version,this.child);

  @override
  Widget build(BuildContext context) {
    WidgetsBinding.instance.addPostFrameCallback((_) {
      if(!checked)
      { _CheckVersion(context,url,app_version); }
      checked = true;
    });
    return Scaffold(body:child);
  }
}
